@@ -7,7 +7,7 @@ use ElasticSearch::Error();
 use ElasticSearch::RequestParser;
 use ElasticSearch::Util qw(throw parse_params);
 
-our $VERSION = '0.50';
+our $VERSION = '0.51';
 our $DEBUG   = 0;
 
 #===================================
@@ -152,7 +152,7 @@ ElasticSearch - An API for communicating with ElasticSearch
 
 =head1 VERSION
 
-Version 0.50, tested against ElasticSearch server version 0.19.0.
+Version 0.51, tested against ElasticSearch server version 0.19.0.
 
 =head1 DESCRIPTION
 
@@ -452,10 +452,12 @@ and L<http://www.elasticsearch.org/guide/reference/modules/thrift.html>
         },
 
         # optional
+        consistency  => 'quorum' | 'one' | 'all',
         create       => 0 | 1,
         parent       => $parent,
         percolate    => $percolate,
         refresh      => 0 | 1,
+        replication  => 'sync' | 'async',
         routing      => $routing,
         timeout      => eg '1m' or '10s'
         version      => int,
@@ -527,9 +529,11 @@ C<set()> is a synonym for L</"index()">
         },
 
         # optional
+        consistency  => 'quorum' | 'one' | 'all',
         parent       => $parent,
         percolate    => $percolate,
         refresh      => 0 | 1,
+        replication  => 'sync' | 'async',
         routing      => $routing,
         timeout      => eg '1m' or '10s',
         version      => int,
